@@ -7,7 +7,7 @@ use warnings;
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 #-------------------------------------------------------------------------------
 1;
@@ -18,7 +18,7 @@ our $VERSION = '0.002'; # VERSION
 
 =for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems cpan testmatrix url
 annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata
-placeholders
+placeholders metacpan
 
 =head1 NAME
 
@@ -26,7 +26,7 @@ Task::Pinto - All the Pinto components in one shot
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 DESCRIPTION
 
@@ -37,14 +37,12 @@ created your own Pinto plugin, let me know so that I can add it here.
 
 =head2 L<Pinto>
 
-=head2 L<App::Pinto::Admin>
-
 =head2 L<Pinto::Remote>
 
-=head2 L<App::Pinto::Remote>
-
 =head2 L<Pinto::Server>
 
+=head2 L<App::Pinto>
+
 =head2 L<Dist::Zilla::Plugin::Pinto::Add>
 
 =head1 SUPPORT
@@ -98,7 +96,7 @@ L<http://www.cpantesters.org/distro/T/Task-Pinto>
 
 CPAN Testers Matrix
 
-The CPAN Testers Matrix is a website that provides a visual way to determine what Perls/platforms PASSed for a distribution.
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
 
 L<http://matrix.cpantesters.org/?dist=Task-Pinto>
 
